about summary refs log tree commit diff
path: root/init/bindings.el
diff options
context:
space:
mode:
Diffstat (limited to 'init/bindings.el')
-rw-r--r--init/bindings.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/init/bindings.el b/init/bindings.el
index c62daad544cd..e6128aaa78e2 100644
--- a/init/bindings.el
+++ b/init/bindings.el
@@ -31,7 +31,7 @@
 (global-set-key (kbd "C-x M") (lambda () (interactive) (eshell t)))
 
 ;; Eval sexp and replace it with result
-(global-set-key (kbd "C-c e") 'esk-eval-and-replace)
+(global-set-key (kbd "C-c e") 'replace-last-sexp)
 
 ;; Start a regular shell if you prefer that.
 (global-set-key (kbd "C-x C-m") 'shell)
@@ -45,8 +45,8 @@
 ;; Add a fullscreen toggle - TODO: reenable in next Emacs release
 ; (global-set-key (kbd "M-RET") 'toggle-frame-fullscreen)
 
-;; Replace standard goto-line with goto-line-with-feedback
-(global-set-key (kbd "M-g g") 'goto-line-with-feedback)
+;; Replace standard goto-line with ace-jump-line-mode
+(global-set-key (kbd "M-g g") 'ace-jump-line-mode)
 
 ;; Goodness from @magnars
 ;; I don't need to kill emacs that easily